@@ -142,6 +142,14 @@ int hook_load( xmlNodePtr parent );
 /* Misc. */
 static Mission *hook_getMission( Hook *hook );
 
+static int should_run_hook( void )
+{
+   // Can't test for PILOT_DEAD or PILOT_EXPLODED or it breaks hooks.
+   // PLAYER_DESTROYED should be set right after exploded if not regenerated.
+   return ( ( player.p != NULL ) && !player_isFlag( PLAYER_DESTROYED ) &&
+            !pilot_isFlag( player.p, PILOT_DELETE ) );
+}
+
 /**
  * Adds a hook to the queue.
  */
@@ -338,12 +346,12 @@ static int hook_runMisn( Hook *hook, const HookParam *param, int claims )
         ( claim_testSys( misn->claims, cur_system->id ) != claims ) )
       return 1;
 
-   /* Delete if only supposed to run once. */
-   if ( hook->once )
-      hook_rmRaw( hook );
-
    /* Set up hook parameters. */
-   misn_runStart( misn, hook->u.misn.func );
+   if ( misn_runStart( misn, hook->u.misn.func ) ) {
+      if ( hook->once )
+         hook_rmRaw( hook );
+      return 0;
+   }
    n = hook_parseParam( param );
 
    /* Add hook parameters. */
@@ -358,8 +366,12 @@ static int hook_runMisn( Hook *hook, const HookParam *param, int claims )
       /* Don't remove hooks on failure, or it can lead to stuck missions (like
        * rehab). */
       // hook_rmRaw( hook );
+      if ( hook->once )
+         hook_rmRaw( hook );
       return -1;
    }
+   if ( hook->once )
+      hook_rmRaw( hook );
    return 0;
 }
 
@@ -384,12 +396,8 @@ static int hook_runEvent( Hook *hook, const HookParam *param, int claims )
         ( event_testClaims( hook->u.event.parent, cur_system->id ) != claims ) )
       return 1;
 
-   /* Delete if only supposed to run once. */
-   if ( hook->once )
-      hook_rmRaw( hook );
-
    /* Set up hook parameters. */
-   if ( event_get( hook->u.event.parent ) == NULL ) {
+   if ( !event_exists( hook->u.event.parent ) ) {
       WARN( _( "Hook [%s] '%d' -> '%s' failed, event does not exist. Deleting "
                "hook." ),
             hook->stack, id, hook->u.event.func );
@@ -397,7 +405,12 @@ static int hook_runEvent( Hook *hook, const HookParam *param, int claims )
       return -1;
    }
 
-   event_runStart( hook->u.event.parent, hook->u.event.func );
+   /* Make sure event is working. */
+   if ( event_runStart( hook->u.event.parent, hook->u.event.func ) ) {
+      if ( hook->once )
+         hook_rmRaw( hook );
+      return 0;
+   }
    n = hook_parseParam( param );
 
    /* Add hook parameters. */
@@ -412,8 +425,13 @@ static int hook_runEvent( Hook *hook, const HookParam *param, int claims )
       /* Don't remove hooks on failure, or it can lead to stuck missions (like
        * rehab). */
       // hook_rmRaw( hook );
+      if ( hook->once )
+         hook_rmRaw( hook );
       return -1;
    }
+
+   if ( hook->once )
+      hook_rmRaw( hook );
    return 0;
 }
 
@@ -788,7 +806,8 @@ void hooks_update( double dt )
 
    /* Don't update without player. */
    if ( ( player.p == NULL ) || player_isFlag( PLAYER_CREATING ) ||
-        player_isFlag( PLAYER_DESTROYED ) )
+        player_isFlag( PLAYER_DESTROYED ) ||
+        pilot_isFlag( player.p, PILOT_DEAD ) )
       return;
 
    /* Clear creation flags. */
@@ -922,7 +941,7 @@ static int hooks_executeParam( const char *stack, const HookParam *param )
    int run;
 
    /* Don't update if player is dead. */
-   if ( ( player.p == NULL ) || player_isFlag( PLAYER_DESTROYED ) )
+   if ( !should_run_hook() )
       return 0;
 
    /* Reset the current stack's ran and creation flags. */
@@ -999,7 +1018,7 @@ int hooks_runParamDeferred( const char *stack, const HookParam *param )
    HookQueue_t *hq;
 
    /* Don't update if player is dead. */
-   if ( ( player.p == NULL ) || player_isFlag( PLAYER_DESTROYED ) )
+   if ( !should_run_hook() )
       return 0;
 
    hq        = calloc( 1, sizeof( HookQueue_t ) );
@@ -1029,7 +1048,7 @@ int hooks_runParamDeferred( const char *stack, const HookParam *param )
 int hooks_runParam( const char *stack, const HookParam *param )
 {
    /* Don't update if player is dead. */
-   if ( ( player.p == NULL ) || player_isFlag( PLAYER_DESTROYED ) )
+   if ( !should_run_hook() )
       return 0;
 
    /* Not time to run hooks, so queue them. */
@@ -1064,16 +1083,15 @@ static Hook *hook_get( unsigned int id )
 }
 
 /**
- * @brief Gets the lua env for a hook.
+ * @brief Gets the Lua environment for a hook.
  */
-nlua_env hook_env( unsigned int hook )
+nlua_env *hook_env( unsigned int hook )
 {
    Mission *misn;
-   Event_t *evt;
 
    Hook *h = hook_get( hook );
    if ( h == NULL )
-      return LUA_NOREF;
+      return NULL;
 
    switch ( h->type ) {
    case HOOK_TYPE_MISN:
@@ -1082,15 +1100,12 @@ nlua_env hook_env( unsigned int hook )
          return misn->env;
       break;
    case HOOK_TYPE_EVENT:
-      evt = event_get( h->u.event.parent );
-      if ( evt != NULL )
-         return evt->env;
-      break;
+      return event_getEnv( h->u.event.parent );
    default:
       break;
    }
 
-   return LUA_NOREF;
+   return NULL;
 }
 
 /**
@@ -1105,7 +1120,7 @@ int hook_runIDparam( unsigned int id, const HookParam *param )
    Hook *h;
 
    /* Don't update if player is dead. */
-   if ( ( player.p == NULL ) || player_isFlag( PLAYER_DESTROYED ) )
+   if ( !should_run_hook() )
       return 0;
 
    /* Try to find the hook and run it. */
