@@ -14,7 +14,7 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 
-#include "SDL_stdinc.h"
+#include <SDL3/SDL_stdinc.h>
 
 #include <errno.h>
 #include <libgen.h> /* dirname / basename */
@@ -23,21 +23,21 @@
 #include <sys/types.h>
 #include <unistd.h>
 #endif /* HAS_POSIX */
-#if __WIN32__
+#if SDL_PLATFORM_WIN32
 #include <windows.h>
-#endif /* __WIN32__ */
+#endif /* SDL_PLATFORM_WIN32 */
 /** @endcond */
 
 #include "nfile.h"
 
 #include "array.h"
 #include "conf.h"
-#if __MACOSX__
+#if SDL_PLATFORM_MACOS
 #include "glue_macos.h"
-#endif /* __MACOSX__ */
+#endif /* SDL_PLATFORM_MACOS */
 #include "log.h"
 
-#if HAS_UNIX && !__MACOSX__
+#if HAS_UNIX && !SDL_PLATFORM_MACOS
 //! http://n.ethz.ch/student/nevillm/download/libxdg-basedir/doc/basedir_8c_source.html
 
 /**
@@ -46,9 +46,9 @@
  *    @param name Name of environment variable.
  *    @return The environment variable or NULL if an error occurs.
  */
-static char *xdgGetEnv( const char *name )
+static const char *xdgGetEnv( const char *name )
 {
-   char *env = SDL_getenv( name );
+   const char *env = SDL_getenv( name );
    if ( ( env != NULL ) && ( env[0] != '\0' ) )
       return env;
    /* What errno signifies missing env var? */
@@ -102,13 +102,14 @@ static char *xdgGetRelativeHome( const char *envname,
    }
    return relhome;
 }
-#endif /* HAS_UNIX && !__MACOSX__ */
+#endif /* HAS_UNIX && !SDL_PLATFORM_MACOS */
 
 static char naev_configPath[PATH_MAX] = "\0"; /**< Store Naev's config path. */
 /**
- * @brief Gets Naev's config path (for user preferences such as conf.lua)
+ * @brief Gets Naev's configuration path (for user preferences such as
+ * "conf.lua")
  *
- *    @return The xdg config path.
+ *    @return The xdg configuration path.
  */
 const char *nfile_configPath( void )
 {
@@ -119,7 +120,7 @@ const char *nfile_configPath( void )
                    conf.datapath );
          return naev_configPath;
       }
-#if __MACOSX__
+#if SDL_PLATFORM_MACOS
       if ( macos_configPath( naev_configPath, sizeof( naev_configPath ) ) !=
            0 ) {
          WARN( _( "Cannot determine config path, using current directory." ) );
@@ -134,140 +135,24 @@ const char *nfile_configPath( void )
 
       snprintf( naev_configPath, sizeof( naev_configPath ), "%s/naev/", path );
       free( path );
-#elif __WIN32__
-      char *path = SDL_getenv( "APPDATA" );
+#elif SDL_PLATFORM_WIN32
+      const char *path = SDL_getenv( "APPDATA" );
       if ( path == NULL ) {
          WARN( _( "%%APPDATA%% isn't set, using current directory." ) );
          path = ".";
       }
       snprintf( naev_configPath, sizeof( naev_configPath ), "%s/naev/", path );
-#elif SDL_VERSION_ATLEAST( 3, 0, 0 )
-      char *prefpath = SDL_GetPrefPath( "Naev DevTeam", "Naev" );
+#else
+      // TODO just use SDL instead of custom implementations?
+      const char *prefpath = SDL_GetPrefPath( ".", "naev" );
       strncpy( naev_configPath, sizeof( naev_configPath ), prefpath );
       SDL_free( prefpath );
-#else
-#error "Feature needs implementation on this Operating System for Naev to work."
 #endif
    }
 
    return naev_configPath;
 }
 
-static char naev_cachePath[PATH_MAX] = "\0"; /**< Store Naev's cache path. */
-/**
- * @brief Gets Naev's cache path (for cached data such as generated textures)
- *
- *    @return The xdg cache path.
- */
-const char *nfile_cachePath( void )
-{
-   if ( naev_cachePath[0] == '\0' ) {
-      /* Global override is set. */
-      if ( conf.datapath ) {
-         snprintf( naev_cachePath, sizeof( naev_cachePath ), "%s/",
-                   conf.datapath );
-         return naev_cachePath;
-      }
-#if __MACOSX__
-      if ( macos_cachePath( naev_cachePath, sizeof( naev_cachePath ) ) != 0 ) {
-         WARN( _( "Cannot determine cache path, using current directory." ) );
-         snprintf( naev_cachePath, sizeof( naev_cachePath ), "./naev/" );
-      }
-#elif HAS_UNIX
-      char *path = xdgGetRelativeHome( "XDG_CACHE_HOME", "/.cache" );
-      if ( path == NULL ) {
-         WARN( _( "$XDG_CACHE_HOME isn't set, using current directory." ) );
-         path = strdup( "." );
-      }
-
-      snprintf( naev_cachePath, sizeof( naev_cachePath ), "%s/naev/", path );
-      free( path );
-#elif __WIN32__
-      char *path = SDL_getenv( "APPDATA" );
-      if ( path == NULL ) {
-         WARN( _( "%%APPDATA%% isn't set, using current directory." ) );
-         path = ".";
-      }
-      snprintf( naev_cachePath, sizeof( naev_cachePath ), "%s/naev/", path );
-#elif SDL_VERSION_ATLEAST( 3, 0, 0 )
-      char *prefpath = SDL_GetPrefPath( "Naev DevTeam", "Naev" );
-      strncpy( naev_cachePath, sizeof( naev_cachePath ), prefpath );
-      SDL_free( prefpath );
-#else
-#error "Feature needs implementation on this Operating System for Naev to work."
-#endif
-   }
-
-   return naev_cachePath;
-}
-
-#if __WIN32__
-#define MKDIR !CreateDirectory( opath, NULL )
-static int mkpath( const char *path )
-#elif HAS_POSIX
-#define MKDIR mkdir( opath, mode )
-static int mkpath( const char *path, mode_t mode )
-#elif SDL_VERSION_ATLEAST( 3, 0, 0 )
-#define MKDIR SDL_CreateDirectory( opath )
-#else
-#error "Feature needs implementation on this Operating System for Naev to work."
-#endif
-{
-   char   opath[PATH_MAX];
-   char  *p;
-   size_t len;
-   int    ret;
-
-   if ( path == NULL )
-      return 0;
-
-   strncpy( opath, path, sizeof( opath ) - 1 );
-   opath[sizeof( opath ) - 1] = '\0';
-   len                        = strlen( opath );
-
-   p = &opath[len - 1];
-   if ( nfile_isSeparator( p[0] ) ) {
-      p[0] = '\0';
-      p--;
-   }
-
-   // Traverse up until we find a directory that exists.
-   for ( ; p >= opath; p-- ) {
-      if ( nfile_isSeparator( p[0] ) ) {
-         p[0] = '\0';
-         if ( nfile_dirExists( opath ) ) {
-            p[0] = '/';
-            break;
-         }
-         p[0] = '/';
-      }
-   }
-   // This skips the directory that exists, or puts us
-   // back at the start if the loop fell through.
-   p++;
-
-   // Traverse down, creating directories.
-   for ( ; p[0] != '\0'; p++ ) {
-      if ( nfile_isSeparator( p[0] ) ) {
-         p[0] = '\0';
-         ret  = MKDIR;
-         if ( ret && ( errno != EEXIST ) )
-            return ret;
-         p[0] = '/';
-      }
-   }
-
-   // Create the final directory.
-   if ( !nfile_dirExists( opath ) ) {
-      ret = MKDIR;
-      if ( ret )
-         return ret;
-   }
-
-   return 0;
-}
-#undef MKDIR
-
 /**
  * @brief Creates a directory if it doesn't exist.
  *
@@ -283,15 +168,7 @@ int nfile_dirMakeExist( const char *path )
    if ( nfile_dirExists( path ) )
       return 0;
 
-#if HAS_POSIX
-   if ( mkpath( path, S_IRWXU | S_IRWXG | S_IRWXO ) < 0 ) {
-#elif __WIN32__
-   if ( mkpath( path ) < 0 ) {
-#elif SDL_VERSION_ATLEAST( 3, 0, 0 )
-   if ( SDL_CreateDirectory( path ) < 0 ) {
-#else
-#error "Feature needs implementation on this Operating System for Naev to work."
-#endif
+   if ( !SDL_CreateDirectory( path ) ) {
       WARN( _( "Dir '%s' does not exist and unable to create: %s" ), path,
             strerror( errno ) );
       return -1;
@@ -350,7 +227,7 @@ int nfile_fileExists( const char *path )
 /**
  * @brief Backup a file, if it exists.
  *
- *    @param path printf formatted string pointing to the file to backup.
+ *    @param path `printf`-formatted string pointing to the file to backup.
  *    @return 0 on success, or if file does not exist, -1 on error.
  */
 int nfile_backupIfExists( const char *path )
@@ -606,10 +483,10 @@ int nfile_isSeparator( uint32_t c )
 {
    if ( c == '/' )
       return 1;
-#if __WIN32__
+#if SDL_PLATFORM_WIN32
    else if ( c == '\\' )
       return 1;
-#endif /* __WIN32__ */
+#endif /* SDL_PLATFORM_WIN32 */
    return 0;
 }
 
@@ -679,12 +556,12 @@ int nfile_simplifyPath( char path[static 1] )
    char  *saveptr  = NULL;
    size_t n        = strlen( path );
    int    absolute = ( path[0] == '/' );
-   char  *token    = SDL_strtokr( path, "/", &saveptr );
+   char  *token    = SDL_strtok_r( path, "/", &saveptr );
 
    while ( token != NULL ) {
       /* Skip noop. */
       if ( ( strcmp( token, "" ) == 0 ) || ( strcmp( token, "." ) == 0 ) ) {
-         token = SDL_strtokr( NULL, "/", &saveptr );
+         token = SDL_strtok_r( NULL, "/", &saveptr );
          continue;
       }
 
@@ -700,7 +577,7 @@ int nfile_simplifyPath( char path[static 1] )
       }
 
       /* On to the next one. */
-      token = SDL_strtokr( NULL, "/", &saveptr );
+      token = SDL_strtok_r( NULL, "/", &saveptr );
    }
 
    /* If nothing, we're empty. */
@@ -725,152 +602,3 @@ int nfile_simplifyPath( char path[static 1] )
    array_free( dirnames );
    return 0;
 }
-
-#if !SDL_VERSION_ATLEAST( 3, 0, 0 )
-#include "nfd.h"
-void SDL_ShowOpenFileDialog( SDL_DialogFileCallback callback, void *userdata,
-                             SDL_Window                 *window,
-                             const SDL_DialogFileFilter *filters,
-                             const char *default_location, SDL_bool allow_many )
-{
-   (void)allow_many;
-   (void)window;
-   char *filelist[2] = { NULL, NULL };
-
-   int n;
-   for ( n = 0; filters[n].name != NULL; n++ )
-      ;
-
-   nfdfilteritem_t *fitem = calloc( n, sizeof( nfdfilteritem_t ) );
-   for ( int i = 0; i < n; i++ ) {
-      fitem[i].name = filters[i].name;
-      fitem[i].spec = filters[i].pattern;
-   }
-
-   NFD_Init();
-
-   nfdchar_t *outPath;
-#if __WIN32__
-   (void)default_location;
-   nfdresult_t result = NFD_OpenDialog( &outPath, fitem, n, NULL );
-#else  /* __WIN32__ */
-   nfdresult_t result = NFD_OpenDialog( &outPath, fitem, n, default_location );
-#endif /* __WIN32__ */
-   switch ( result ) {
-   case NFD_OKAY:
-      filelist[0] = outPath;
-      callback( userdata, (const char **)filelist, 0 );
-      NFD_FreePath( outPath );
-      break;
-
-   case NFD_CANCEL:
-      callback( userdata, (const char **)filelist, 0 );
-      break;
-
-   default:
-      SDL_SetError( "%s", NFD_GetError() );
-      callback( userdata, NULL, -1 );
-      break;
-   }
-
-   NFD_Quit();
-
-   free( fitem );
-}
-
-void SDL_ShowOpenFolderDialog( SDL_DialogFileCallback callback, void *userdata,
-                               SDL_Window *window, const char *default_location,
-                               SDL_bool allow_many )
-{
-   (void)allow_many;
-   (void)window;
-   char *filelist[2] = { NULL, NULL };
-
-   NFD_Init();
-
-   nfdchar_t *outPath;
-#if __WIN32__
-   (void)default_location;
-   nfdresult_t result = NFD_PickFolder( &outPath, NULL );
-#else  /* __WIN32__ */
-   nfdresult_t result = NFD_PickFolder( &outPath, default_location );
-#endif /* __WIN32__ */
-   switch ( result ) {
-   case NFD_OKAY:
-      filelist[0] = outPath;
-      callback( userdata, (const char **)filelist, 0 );
-      NFD_FreePath( outPath );
-      break;
-
-   case NFD_CANCEL:
-      callback( userdata, (const char **)filelist, 0 );
-      break;
-
-   default:
-      SDL_SetError( "%s", NFD_GetError() );
-      callback( userdata, NULL, -1 );
-      break;
-   }
-
-   NFD_Quit();
-}
-
-void SDL_ShowSaveFileDialog( SDL_DialogFileCallback callback, void *userdata,
-                             SDL_Window                 *window,
-                             const SDL_DialogFileFilter *filters,
-                             const char                 *default_location )
-{
-   (void)window;
-   char *filelist[2] = { NULL, NULL };
-   char *tmp, *bname, *dname;
-
-   int n;
-   for ( n = 0; filters[n].name != NULL; n++ )
-      ;
-
-   nfdfilteritem_t *fitem = calloc( n, sizeof( nfdfilteritem_t ) );
-   for ( int i = 0; i < n; i++ ) {
-      fitem[i].name = filters[i].name;
-      fitem[i].spec = filters[i].pattern;
-   }
-
-   /* Get paths. */
-   tmp   = strdup( default_location );
-   dname = strdup( dirname( tmp ) );
-   free( tmp );
-   tmp   = strdup( default_location );
-   bname = strdup( basename( tmp ) );
-   free( tmp );
-
-   NFD_Init();
-
-   nfdchar_t *outPath;
-#if __WIN32__
-   nfdresult_t result = NFD_SaveDialog( &outPath, fitem, n, NULL, bname );
-#else  /* __WIN32__ */
-   nfdresult_t result = NFD_SaveDialog( &outPath, fitem, n, dname, bname );
-#endif /* __WIN32__ */
-   switch ( result ) {
-   case NFD_OKAY:
-      filelist[0] = outPath;
-      callback( userdata, (const char **)filelist, 0 );
-      NFD_FreePath( outPath );
-      break;
-
-   case NFD_CANCEL:
-      callback( userdata, (const char **)filelist, 0 );
-      break;
-
-   default:
-      SDL_SetError( "%s", NFD_GetError() );
-      callback( userdata, NULL, -1 );
-      break;
-   }
-
-   NFD_Quit();
-
-   free( dname );
-   free( bname );
-   free( fitem );
-}
-#endif /* ! SDL_VERSION_ATLEAST(3,0,0) */
